<?php defined('BASEPATH') OR exit('No direct script access allowed'); ?>

ERROR - 2024-01-26 00:30:03 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
<?php defined('BASEPATH') OR exit('No direct script access allowed'); ?>

ERROR - 2024-01-26 00:30:03 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-01-26 09:01:45 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-01-26 09:01:45 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-01-26 16:39:14 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-01-26 16:39:14 --> 404 Page Not Found: Robotstxt/index
ERROR - 2024-01-26 16:39:15 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-01-26 16:39:15 --> 404 Page Not Found: Enhancecp/index
